@@ -77,4 +77,7 @@ class Balance(NopeCHAObject):
 
     @classmethod
     def get(cls, **params):
-        return cls().request("get", cls.get_url(), params)
+        r = cls().request("get", cls.get_url(), params)
+        if isinstance(r, nopecha.error.NopeCHAError):
+            raise r
+        return r
